@@ -243,9 +243,12 @@ IWRatchetConsensus <- function (tree, dataset, ratchHits=10, concavity=4,
                               swappers=list(RootedNNISwap), nSearch=10, 
                               suboptimal=suboptimal,
                               stopAtScore=NULL, ...) {
-  trees <- lapply(logical(nSearch), function (x) IWRatchet(tree, dataset, ratchIter=1, 
-                                                         searchIter=searchIter, searchHits=searchHits, verbosity=verbosity, swappers=swappers, 
-                                                         stopAtScore=stopAtScore, ...))
+  trees <- lapply(logical(nSearch), 
+                  function (x) 
+                    IWRatchet(tree, dataset, ratchIter=1, concavity=concavity,
+                              searchIter=searchIter, searchHits=searchHits, 
+                              verbosity=verbosity, swappers=swappers, 
+                              stopAtScore=stopAtScore, ...))
   scores <- vapply(trees, function (x) attr(x, 'score'), double(1))
   trees <- unique(trees[scores == min(scores)])
   cat ("Found", length(trees), 'unique trees from', nSearch, 'searches.')
