@@ -1,6 +1,6 @@
 library(ape)
 
-context("Tree ordering functions")
+context("Arboriculture: Tree ordering functions")
 test_that("replacement reorder functions work correctly", {
   ## Tree
   tree <- read.tree(text = "((((((1,2),3),4),5),6),(7,(8,(9,(10,(11,12))))));")
